# geomind


[![image](https://img.shields.io/pypi/v/geomind.svg)](https://pypi.python.org/pypi/geomind)
[![image](https://img.shields.io/conda/vn/conda-forge/geomind.svg)](https://anaconda.org/conda-forge/geomind)


**Geoai package**


-   Free software: MIT License
-   Documentation: https://Iamnyatichi.github.io/geomind
    

## Features

-   TODO
